/**
 * @class EntitySchema
 * @property {string} nameProp The name that will be used for normalized entities of this type
 * @property {Function} idFunction A function used to get the ID value for a single entity
 * @property {Function} processFunction A function used to convert the input type before normalizing
 * @property {Object<string, Schema>} props A map of properties of the entity type to the names of other schemas
 */
export class EntitySchema {
    constructor(name: any, idFunction: any, props: any, schemas: any, processFunction: any);
    /**
     * @type {string}
     */
    nameProp: string;
    /**
     * @type {Function}
     */
    idFunction: Function;
    /**
     * @type {Function}
     */
    processFunction: Function;
    /**
     * @type {Object<string, string>}
     */
    props: {
        [x: string]: string;
    };
    normalizeWith(input: any, parent: any, objectKey: any): {
        result: any;
        entities: {
            [x: string]: {
                [x: number]: {};
            };
        };
    };
    normalize(input: any): {
        result: any;
        entities: {
            [x: string]: {
                [x: number]: {};
            };
        };
    };
    normalizeManyWith(input: any, parent: any, objectKey: any): {
        result: never[];
        entities: {};
    };
    normalizeMany(input: any): {
        result: never[];
        entities: {};
    };
}
/**
 * @class EntityBuilder
 * @property {Function} idFunction A function used to get the ID value for a single entity
 * @property {Function} processFunction A function used to convert the input type before normalizing
 * @property {string} nameProp The name that will be used for normalized entities of this type
 * @property {Object<string, string>} props A map of properties of the entity type to the names of other schemas
 * @property {Object<string, EntitySchema>} schemas A map of the names of other schemas to their schema classes
 */
export class EntityBuilder {
    constructor(id: any, name: any, props: any, schemas: any, processFunction: any);
    /**
     * @type {string}
     */
    nameProp: string;
    /**
     * @type {Function}
     */
    idFunction: Function;
    /**
     * @type {Function}
     */
    processFunction: Function;
    /**
     * @type {Object<string, string>}
     */
    props: {
        [x: string]: string;
    };
    /**
     * @type {Object<string, EntitySchema>}
     */
    schemas: {
        [x: string]: EntitySchema;
    };
    name(name: any): EntityBuilder;
    id(id: any): EntityBuilder;
    prop(propName: any, propValue: any): EntityBuilder;
    define(schema: any): EntityBuilder;
}
